{
    "$graph": [
        {
            "class": "CommandLineTool",
            "doc": "hash input through md5",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kubler/openssl:20190330"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 20,
                    "outdirMin": 100
                }
            ],
            "inputs": [
                {
                    "id": "#hashsplitter-md5.cwl.yml/input",
                    "type": "File",
                    "doc": "original content",
                    "inputBinding": {
                        "position": 1
                    }
                }
            ],
            "stdout": "md5",
            "baseCommand": [
                "openssl",
                "dgst"
            ],
            "arguments": [
                "-md5"
            ],
            "id": "#hashsplitter-md5.cwl.yml",
            "outputs": [
                {
                    "id": "#hashsplitter-md5.cwl.yml/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "md5"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "doc": "hash input through sha",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kubler/openssl:20190330"
                }
            ],
            "inputs": [
                {
                    "id": "#hashsplitter-sha.cwl.yml/input",
                    "type": "File",
                    "doc": "original content",
                    "inputBinding": {
                        "position": 1
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#hashsplitter-sha.cwl.yml/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "sha"
                    }
                }
            ],
            "stdout": "sha",
            "baseCommand": [
                "openssl",
                "dgst"
            ],
            "arguments": [
                "-sha"
            ],
            "id": "#hashsplitter-sha.cwl.yml"
        },
        {
            "class": "CommandLineTool",
            "doc": "unify hashed values into a single output",
            "hints": [
                {
                    "dockerPull": "frolvlad/alpine-bash@sha256:56604451924532bbf5e600107ac75ef8fe87827aade79cd2d58c81bacb5f9029",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#hashsplitter-unify.cwl.yml/md5"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#hashsplitter-unify.cwl.yml/sha"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#hashsplitter-unify.cwl.yml/whirlpool"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#hashsplitter-unify.cwl.yml/output",
                    "outputBinding": {
                        "glob": "unify"
                    }
                }
            ],
            "stdout": "unify",
            "baseCommand": [
                "cat"
            ],
            "id": "#hashsplitter-unify.cwl.yml"
        },
        {
            "class": "CommandLineTool",
            "doc": "hash input through sha512",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kubler/openssl:20190330"
                }
            ],
            "inputs": [
                {
                    "id": "#hashsplitter-whirlpool.cwl.yml/input",
                    "type": "File",
                    "doc": "original content",
                    "inputBinding": {
                        "position": 1
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#hashsplitter-whirlpool.cwl.yml/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "whirlpool"
                    }
                }
            ],
            "stdout": "whirlpool",
            "baseCommand": [
                "openssl",
                "dgst"
            ],
            "arguments": [
                "-sha512"
            ],
            "id": "#hashsplitter-whirlpool.cwl.yml"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "id": "#main/input",
                    "type": "File",
                    "doc": "to be hashed all the ways"
                }
            ],
            "outputs": [
                {
                    "id": "#main/output",
                    "type": "File",
                    "outputSource": "#main/unify/output"
                }
            ],
            "steps": [
                {
                    "id": "#main/md5",
                    "run": "#hashsplitter-md5.cwl.yml",
                    "in": [
                        {
                            "id": "#main/md5/input",
                            "source": "#main/input"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/md5/output"
                        }
                    ]
                },
                {
                    "id": "#main/sha",
                    "run": "#hashsplitter-sha.cwl.yml",
                    "in": [
                        {
                            "id": "#main/sha/input",
                            "source": "#main/input"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/sha/output"
                        }
                    ]
                },
                {
                    "id": "#main/whirlpool",
                    "run": "#hashsplitter-whirlpool.cwl.yml",
                    "in": [
                        {
                            "id": "#main/whirlpool/input",
                            "source": "#main/input"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/whirlpool/output"
                        }
                    ]
                },
                {
                    "id": "#main/unify",
                    "run": "#hashsplitter-unify.cwl.yml",
                    "in": [
                        {
                            "id": "#main/unify/md5",
                            "source": "#main/md5/output"
                        },
                        {
                            "id": "#main/unify/sha",
                            "source": "#main/sha/output"
                        },
                        {
                            "id": "#main/unify/whirlpool",
                            "source": "#main/whirlpool/output"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/unify/output"
                        }
                    ]
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
